| tripaccess | R Documentation |
Include disability and other demographic as well as mobility and trip categorical and numeric variables for data visualization and single table analysis.
tripaccess
A data frame with 86521 rows (each row is a person) and 41 columns
Household identifier.
Person identifier.
How long does the respondent have a medical condition that makes it difficult to travel outside of home?
Sex of the respondent.
Race of the respondent.
Hispanic or Latino origin.
Born in United States.
Age of the respondent.
Educational attainment.
Opinion of health.
Primary activity in previous week.
Household income of the respondent.
Count of household members.
Category of population density (persons per square mile) in the census block group of the households home location.
Household in urban or rural area.
Household state.
Driver status.
Does the respondent use a cane to aid their travel?
Does the respondent use a manual wheelchair to aid their travel?
Does the respondent use a crutch to aid their travel?
Does the respondent use a dog to aid their travel?
Does the respondent use a motorized wheelchair to aid their travel?
Does the respondent use a scooter to aid their travel?
Does the respondent use a white cane to aid their travel?
Does the respondent use a walker to aid their travel?
Does the respondent use any other accommodation rather than those listed?
Miles personally drive in all vehicles.
Count of public transit usage in last month.
Count of rideshare app usage in last month.
Count of bike trips in past week.
Count of walk trips in past week.
Count of times purchased online for delivery in last 30 days.
Average number of people on the respondent's trip including the respondent on the respondent's travel day. A travel day is a 24 hour day that starts at 4 am (local time) of the assigned travel day and ends at 3:59 am of the following day. The NHTS randomly assigns the travel days for one-seventh of the sample addresses to each day of the week and the remaining six-sevenths of the households to evenly across weekdays (Monday to Friday). The following variables are related to trip information on travel day.
Average trip distance in miles on the respondent's travel day.
Average trip duration in minutes on the respondent's travel day.
Whether having shopping trips on the respondent's travel day.
Whether having social or recreational trips on the respondent's travel day.
Whether having other home-based trips on the respondent's travel day.
Whether having work trips on the respondent's travel day.
Whether having other non home-based trips on the respondent's travel day.
Person weights that can be used for person-level estimates of non-household and non-travel day items of interest, for example workers by gender, drivers by annual miles estimated, etc.
if (require("tidyverse")) {
# Filtered to people who have a travel disability
tripaccess_disabled <- tripaccess |>
filter(travel_disability != "No_disability")
# Summary statistics of public transit usage by disabled people who use a walker
tripaccess_disabled |>
filter(walker == "True") |>
group_by(travel_disability) |>
summarize(public_transit_usage_median = median(count_of_public_transit_usage),
public_transit_usage_mean = mean(count_of_public_transit_usage),
public_transit_usage_sd = sd(count_of_public_transit_usage))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.